@@ -25,6 +25,7 @@ from typing import Optional, Dict, List, Set, Union
 
 import github
 from github import UnknownObjectException
+from github.GithubException import GithubException
 from github.Repository import Repository
 from github.CommitComment import CommitComment as GithubCommitComment
 from github.GitRelease import GitRelease as PyGithubRelease
@@ -124,6 +125,15 @@ class GithubProject(BaseGitProject):
             logger.debug(f"Project {self.repo}/{user_login} does not exist: {ex}")
             return None
 
+    def exists(self) -> bool:
+        try:
+            _ = self.github_repo
+            return True
+        except UnknownObjectException as ex:
+            if "Not Found" in str(ex):
+                return False
+            raise GithubAPIException from ex
+
     def is_private(self) -> bool:
         """
         Is this repo private? (accessible only by users with granted access)
@@ -160,6 +170,10 @@ class GithubProject(BaseGitProject):
             else None
         )
 
+    @property
+    def default_branch(self):
+        return self.github_repo.default_branch
+
     def get_branches(self) -> List[str]:
         return [branch.name for branch in self.github_repo.get_branches()]
 
@@ -421,7 +435,8 @@ class GithubProject(BaseGitProject):
     def change_token(self, new_token: str):
         raise NotImplementedError
 
-    def get_file_content(self, path: str, ref="master") -> str:
+    def get_file_content(self, path: str, ref=None) -> str:
+        ref = ref or self.default_branch
         try:
             return self.github_repo.get_contents(
                 path=path, ref=ref
@@ -430,15 +445,16 @@ class GithubProject(BaseGitProject):
             raise FileNotFoundError(f"File '{path}' on {ref} not found", ex)
 
     def get_files(
-        self, ref: str = "master", filter_regex: str = None, recursive: bool = False
+        self, ref: str = None, filter_regex: str = None, recursive: bool = False
     ) -> List[str]:
         """
         Get a list of file paths of the repo.
-        :param ref: branch or commit (defaults to master)
+        :param ref: branch or commit (defaults to repo's default branch)
         :param filter_regex: filter the paths with re.search
         :param recursive: whether to return only top directory files or all files recursively
         :return: [str]
         """
+        ref = ref or self.default_branch
         paths = []
         contents = self.github_repo.get_contents(path="", ref=ref)
 
@@ -559,11 +575,17 @@ class GithubProject(BaseGitProject):
             raw_release=release, git_tag=self.get_tag_from_tag_name(release.tag_name)
         )
 
-    def get_latest_release(self) -> GithubRelease:
-        release = self.github_repo.get_latest_release()
-        return self._release_from_github_object(
-            raw_release=release, git_tag=self.get_tag_from_tag_name(release.tag_name)
-        )
+    def get_latest_release(self) -> Optional[GithubRelease]:
+        try:
+            release = self.github_repo.get_latest_release()
+            return self._release_from_github_object(
+                raw_release=release,
+                git_tag=self.get_tag_from_tag_name(release.tag_name),
+            )
+        except GithubException as ex:
+            if ex.status == 404:
+                return None
+            raise GithubAPIException from ex
 
     def get_releases(self) -> List[Release]:
         releases = self.github_repo.get_releases()
