@@ -20,8 +20,10 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from typing import Optional, Type
+import logging
+from typing import Optional, Type, Union
 
+from urllib3.util import Retry
 import github
 import github.GithubObject
 from github import (
@@ -43,6 +45,8 @@ from ogr.services.github.auth_providers import (
 )
 from ogr.services.github.user import GithubUser
 
+logger = logging.getLogger(__name__)
+
 
 @use_for_service("github.com")
 class GithubService(BaseGitService):
@@ -59,7 +63,8 @@ class GithubService(BaseGitService):
         github_app_private_key_path: str = None,
         tokman_instance_url: str = None,
         github_authentication: GithubAuthentication = None,
-        **_,
+        max_retries: Union[int, Retry] = 0,
+        **kwargs,
     ):
         """
         If multiple authentication methods are provided, they are prioritised:
@@ -71,6 +76,19 @@ class GithubService(BaseGitService):
         self.read_only = read_only
         self.authentication = github_authentication
 
+        if isinstance(max_retries, Retry):
+            self._max_retries = max_retries
+        else:
+            self._max_retries = Retry(
+                total=int(max_retries),
+                read=0,
+                # Retry mechanism active for these HTTP methods:
+                method_whitelist=["DELETE", "GET", "PATCH", "POST", "PUT"],
+                # Only retry on following HTTP status codes
+                status_forcelist=[500, 503, 403, 401],
+                raise_on_status=False,
+            )
+
         if not self.authentication:
             self.__set_authentication(
                 token=token,
@@ -78,8 +96,11 @@ class GithubService(BaseGitService):
                 github_app_private_key=github_app_private_key,
                 github_app_private_key_path=github_app_private_key_path,
                 tokman_instance_url=tokman_instance_url,
+                max_retries=self._max_retries,
             )
 
+        logger.warning(f"Ignored keyword arguments: {kwargs}")
+
     def __set_authentication(self, **kwargs):
         auth_methods = [
             Tokman,
@@ -177,4 +198,4 @@ class GithubService(BaseGitService):
 
     def get_pygithub_instance(self, namespace: str, repo: str) -> PyGithubInstance:
         token = self.authentication.get_token(namespace, repo)
-        return PyGithubInstance(login_or_token=token)
+        return PyGithubInstance(login_or_token=token, retry=self._max_retries)
