@@ -21,7 +21,7 @@
 # SOFTWARE.
 
 import logging
-from typing import List, Optional, Dict, Set
+from typing import List, Optional, Dict, Set, Iterable
 from urllib.parse import urlparse
 
 from ogr.abstract import (
@@ -49,7 +49,7 @@ from ogr.services.pagure.flag import PagureCommitFlag
 from ogr.services.pagure.issue import PagureIssue
 from ogr.services.pagure.pull_request import PagurePullRequest
 from ogr.services.pagure.release import PagureRelease
-from ogr.utils import RequestResponse
+from ogr.utils import RequestResponse, filter_paths
 
 logger = logging.getLogger(__name__)
 
@@ -178,6 +178,11 @@ class PagureProject(BaseGitProject):
         return_value = self._call_project_api("git", "branches", method="GET")
         return return_value["branches"]
 
+    @property
+    def default_branch(self) -> str:
+        return_value = self._call_project_api("git", "branches", method="GET")
+        return return_value["default"]
+
     def get_description(self) -> str:
         return self.get_project_info()["description"]
 
@@ -267,6 +272,7 @@ class PagureProject(BaseGitProject):
             body=body,
             target_branch=target_branch,
             source_branch=source_branch,
+            fork_username=fork_username,
         )
 
     @if_readonly(return_function=GitProjectReadOnly.fork_create)
@@ -426,7 +432,8 @@ class PagureProject(BaseGitProject):
         """
         self.service.change_token(new_token)
 
-    def get_file_content(self, path: str, ref="master") -> str:
+    def get_file_content(self, path: str, ref=None) -> str:
+        ref = ref or self.default_branch
         try:
             result = self._call_project_api_raw(
                 "raw", ref, "f", path, add_api_endpoint_part=False
@@ -539,3 +546,31 @@ class PagureProject(BaseGitProject):
         fork = f"fork/{self._user}/" if self.is_fork else ""
         namespace = f"{self.namespace}/" if self.namespace else ""
         return f"{fork}{namespace}{self.repo}"
+
+    def __get_files(
+        self, path: str, ref: str = None, recursive: bool = False
+    ) -> Iterable[str]:
+        subfolders = ["."]
+
+        while subfolders:
+            path = subfolders.pop()
+            split_path = []
+            if path != ".":
+                split_path = ["f"] + path.split("/")
+            response = self._call_project_api("tree", ref, *split_path)
+
+            for file in response["content"]:
+                if file["type"] == "file":
+                    yield file["path"]
+                elif recursive and file["type"] == "folder":
+                    subfolders.append(file["path"])
+
+    def get_files(
+        self, ref: str = None, filter_regex: str = None, recursive: bool = False
+    ) -> List[str]:
+        ref = ref or self.default_branch
+        paths = list(self.__get_files(".", ref, recursive))
+        if filter_regex:
+            paths = filter_paths(paths, filter_regex)
+
+        return paths
