@@ -4,6 +4,8 @@ import pytest
 from flexmock import Mock
 from flexmock import flexmock
 
+from urllib3.util import Retry
+
 from ogr import PagureService, GitlabService, GithubService
 from ogr.exceptions import OgrException
 from ogr.factory import get_service_class, get_project, get_instances_from_dict
@@ -57,12 +59,13 @@ def test_get_service_class_not_found(url, mapping):
 
 
 @pytest.mark.parametrize(
-    "url,mapping,instances,result",
+    "url,mapping,instances,force_custom_instance,result",
     [
         (
             "https://github.com/packit-service/ogr",
             None,
             None,
+            True,
             GithubProject(
                 namespace="packit-service", repo="ogr", service=GithubService()
             ),
@@ -71,6 +74,7 @@ def test_get_service_class_not_found(url, mapping):
             "github.com/packit-service/ogr",
             None,
             None,
+            True,
             GithubProject(
                 namespace="packit-service", repo="ogr", service=GithubService()
             ),
@@ -79,6 +83,7 @@ def test_get_service_class_not_found(url, mapping):
             "git@github.com:packit-service/ogr.git",
             None,
             None,
+            True,
             GithubProject(
                 namespace="packit-service", repo="ogr", service=GithubService()
             ),
@@ -87,6 +92,7 @@ def test_get_service_class_not_found(url, mapping):
             "https://some-url/packit-service/ogr",
             {"some-url": GithubService},
             None,
+            True,
             GithubProject(
                 namespace="packit-service", repo="ogr", service=GithubService()
             ),
@@ -95,6 +101,7 @@ def test_get_service_class_not_found(url, mapping):
             "https://github.com/packit-service/ogr",
             {"github.com": PagureService},
             None,
+            True,
             PagureProject(
                 namespace="packit-service",
                 repo="ogr",
@@ -105,6 +112,7 @@ def test_get_service_class_not_found(url, mapping):
             "https://src.fedoraproject.org/rpms/python-ogr",
             None,
             None,
+            True,
             PagureProject(
                 namespace="rpms",
                 repo="python-ogr",
@@ -115,6 +123,7 @@ def test_get_service_class_not_found(url, mapping):
             "https://pagure.io/ogr",
             None,
             None,
+            True,
             PagureProject(
                 repo="ogr",
                 namespace=None,
@@ -131,6 +140,7 @@ def test_get_service_class_not_found(url, mapping):
                     get_project_from_url=lambda url: "project",
                 )
             ],
+            True,
             "project",
         ),
         (
@@ -148,12 +158,14 @@ def test_get_service_class_not_found(url, mapping):
                     get_project_from_url=lambda url: "right-project",
                 ),
             ],
+            True,
             "right-project",
         ),
         (
             "https://gitlab.gnome.org/lbarcziova/testing-ogr-repo",
             None,
             None,
+            True,
             GitlabProject(
                 repo="testing-ogr-repo",
                 namespace="lbarcziova",
@@ -164,6 +176,7 @@ def test_get_service_class_not_found(url, mapping):
             "https://src.stg.fedoraproject.org/rpms/python-dockerpty.git",
             None,
             [PagureService(instance_url="https://src.stg.fedoraproject.org")],
+            True,
             PagureProject(
                 repo="python-dockerpty",
                 namespace="rpms",
@@ -177,17 +190,34 @@ def test_get_service_class_not_found(url, mapping):
                 PagureService(instance_url="https://src.stg.fedoraproject.org"),
                 PagureService(instance_url="https://src.fedoraproject.org"),
             ],
+            False,
             PagureProject(
                 repo="python-dockerpty",
                 namespace="rpms",
                 service=PagureService(instance_url="https://src.fedoraproject.org"),
             ),
         ),
+        (
+            "https://github.com/packit/ogr",
+            None,
+            [
+                PagureService(instance_url="https://src.fedoraproject.org"),
+            ],
+            False,
+            GithubProject(
+                repo="ogr",
+                namespace="packit",
+                service=GithubService(instance_url="https://github.com/packit/ogr"),
+            ),
+        ),
     ],
 )
-def test_get_project(url, mapping, instances, result):
+def test_get_project(url, mapping, instances, force_custom_instance, result):
     project = get_project(
-        url=url, service_mapping_update=mapping, custom_instances=instances
+        url=url,
+        service_mapping_update=mapping,
+        custom_instances=instances,
+        force_custom_instance=force_custom_instance,
     )
     assert project == result
 
@@ -337,12 +367,86 @@ def test_get_instances_from_dict(instances_in_dict, result_instances: Set):
             },
             {GithubService(tokman_instance_url="http://localhost")},
         ),
+        (
+            {
+                "gitlab.com": {
+                    "type": "gitlab",
+                    "instance_url": "https://gitlab.com",
+                    "token": "my_very_secret_token",
+                }
+            },
+            {
+                GitlabService(
+                    instance_url="https://gitlab.com", token="my_very_secret_token"
+                )
+            },
+        ),
     ],
 )
 def test_get_instances_from_dict_multiple_auth(instances_in_dict, result_instances):
     assert get_instances_from_dict(instances=instances_in_dict) == result_instances
 
 
+@pytest.mark.parametrize(
+    "instances_in_dict,result_max_retries_total",
+    [
+        (
+            {
+                "github.com": {
+                    "token": "abcd",
+                }
+            },
+            0,
+        ),
+        (
+            {
+                "github.com": {
+                    "token": "abcd",
+                    "max_retries": "3",
+                }
+            },
+            3,
+        ),
+        (
+            {
+                "github.com": {
+                    "token": "abcd",
+                    "max_retries": 3,
+                }
+            },
+            3,
+        ),
+        (
+            {
+                "github.com": {
+                    "tokman_instance_url": "http://localhost",
+                    "max_retries": 3,
+                }
+            },
+            3,
+        ),
+        (
+            {
+                "github.com": {
+                    "github_app_id": "123",
+                    "max_retries": 3,
+                }
+            },
+            3,
+        ),
+    ],
+)
+def test_get_github_instance_with_retries(instances_in_dict, result_max_retries_total):
+    instances = get_instances_from_dict(instances_in_dict)
+
+    assert instances
+    ghs_instance = instances.pop()
+    assert isinstance(ghs_instance, GithubService)
+    max_retries = ghs_instance._max_retries
+    assert isinstance(max_retries, Retry)
+    assert max_retries.total == result_max_retries_total
+
+
 @pytest.mark.parametrize(
     "instances_in_dict,error_str",
     [
